/*SD read/write code modified from https://docs.arduino.cc/learn/programming/sd-guide/
SEEED Libraries:
https://github.com/Seeed-Studio/Grove_BME280	(v1.0.2)
https://github.com/Seeed-Studio/RTC_DS1307	(v1.0.0)
*/

#include <SPI.h>
#include <SD.h>
#include "Seeed_BME280.h"
#include <Wire.h>
#include "DS1307.h"
BME280 bme280;
DS1307 clock;

File myFile;

void setup() {
  // Open serial communications and wait for port to open:
  Serial.begin(9600);
  clock.begin();

  //For initial setup of the RTC
  //clock.fillByYMD(2024,5,15); //Example: March 15, 2024 at 1:00 PM
  //clock.fillByHMS(13,00,00); //(in 24-hour format)
  //clock.setTime(); //write time to the RTC chip

  if(!bme280.init()){
	Serial.println("Device error!");
  } //*
  while (!Serial) {
	; // wait for the serial port to connect. Needed for native USB port only
  }

  Serial.print("Initializing SD card...");

  if (!SD.begin(4)) {
	Serial.println("initialization failed!");
	while (1);
  }
  Serial.println("initialization done.");

  // open the file. note that only one file can be open at a time,
  // so you have to close this one before opening another.
  myFile = SD.open("data.txt", FILE_WRITE);

  // if the file opened okay, write to it:
  if (myFile) {
	Serial.print("Writing to file...");
	myFile.print("Date");
	myFile.print("\t");
	myFile.print("Time");
	myFile.print("\t");
	myFile.print("Temperature");
	myFile.print("\t");
	myFile.print("Pressure");
	myFile.print("\t");
	myFile.print("Altitude");
	myFile.print("\t");
	myFile.println("Humidity"); //column names
	// close the file: (saves the data)
	myFile.close();
	Serial.println("done.");
  } else {
	// if the file didn't open, print an error:
	Serial.println("error opening file");
  }

  // re-open the file for reading:
  myFile = SD.open("data.txt");
  if (myFile) {
	Serial.println("opened file:");

	// read from the file until there's nothing else in it:
	while (myFile.available()) {
  	Serial.write(myFile.read());
	}
	// close the file:
	myFile.close();
  } else {
	// if the file didn't open, print an error:
	Serial.println("error opening file");
  }
}

void loop()
  {
	myFile = SD.open("data.txt", FILE_WRITE);
  	float pressure;
  	clock.getTime();

  	myFile.print(clock.month, DEC);
  	myFile.print("-");
  	myFile.print(clock.dayOfMonth, DEC);
  	myFile.print("-");
  	myFile.print(clock.year+2000, DEC);
  	myFile.print("\t");
  	myFile.print(clock.hour, DEC);
  	myFile.print(":");
  	myFile.print(clock.minute, DEC);
  	myFile.print(":");
  	myFile.print(clock.second, DEC);
  	myFile.print("\t");
  	myFile.print(bme280.getTemperature());
  	myFile.print("\t");
  	myFile.print(pressure = bme280.getPressure());
  	myFile.print("\t");
  	myFile.print(bme280.calcAltitude(pressure));
  	myFile.print("\t");
  	myFile.println(bme280.getHumidity());
 	 
  	//For testing in IDE
  	Serial.print("Date (MDY): ");
  	Serial.print(clock.month, DEC);
  	Serial.print("-");
  	Serial.print(clock.dayOfMonth, DEC);
  	Serial.print("-");
  	Serial.println(clock.year+2000, DEC);
  	Serial.print("Time (HMS): ");
  	Serial.print(clock.hour, DEC);
  	Serial.print(":");
  	Serial.print(clock.minute, DEC);
  	Serial.print(":");
  	Serial.println(clock.second, DEC);
  	Serial.print("Temperature: ");
  	Serial.print(bme280.getTemperature());
  	Serial.println("C"); //degrees Celsius
  	Serial.print("Pressure: ");
  	Serial.print(pressure = bme280.getPressure());
  	Serial.println("Pa"); //Pascals
  	Serial.print("Pressure Altitude: ");
  	Serial.print(bme280.calcAltitude(pressure));
  	Serial.println("m"); //meters
  	Serial.print("Relative Humidity: ");
  	Serial.print(bme280.getHumidity());
  	Serial.println("%"); //percent
  	Serial.println();

  	delay(3000); //record data every 3 seconds
  	myFile.close();
  }